
###### WELCOME TO ME PROJECT ######
   $ pip install cryptodo 


module use by :

   crypto V1 use:

  $ 1.import cryptodo 
  
    ##### encryption text #####
  
  $ 2.a = cryptodo.crypto('text',key_number)
  $ 3.print(a.encrypt())
  
  
  ##### decrypiton text #####
   
    4.b = cryptodo.crypto('encrypt_text',key_number)    
    5.print(b.decrypt())
  
    
    crypto_V2 use:
         
         encryipt
         
    6. k = cryptodo.crypto_V2('text',key)
    7. k.encrypt()   #print or var
         
         decryipt
     
     8. l = cryptodo.crypto_V2('encrypt_text',key)
     9. l.decrypt()
     
     more........ect
 scripting by k.a. ishan oshada(index)
 🤳🙏
  

  